@@ -27,8 +27,6 @@ pub mod encoding {
 }
 pub use canadensis_core::nb;
 
-mod hash;
-
 pub mod anonymous;
 pub mod node;
 mod publisher;
@@ -446,6 +444,17 @@ impl<T> PublishToken<T> {
     }
 }
 
+mod fmt_impl {
+    use super::PublishToken;
+    use core::fmt::{Debug, Formatter, Result};
+
+    impl<T> Debug for PublishToken<T> {
+        fn fmt(&self, f: &mut Formatter<'_>) -> Result {
+            f.debug_tuple("PublishToken").field(&self.0).finish()
+        }
+    }
+}
+
 /// A token returned from [`Node::start_sending_requests`](Node#tymethod.start_sending_requests)
 /// that can be used to a request a service using the associated service ID
 ///
